--************************************************************************
--  serial.ads
--
--  Written by:  C1C Hugh O'Donnell
--               C1C Robin Stephens
--               Lt. Col. Joiner
--               Dr. Martin C. Carlisle
--
--  Send comments to:  carlislem@acm.org
--
--  Description:  This program is an example of serial port communication 
--                via Win32 binding.  Must
-- 		         be run on a computer running Windoze 95 or Windoze NT.
--************************************************************************

package serial is

   type Byte is new Natural range 0..255;
   for Byte'size use 8;

   -- raised if we detect an error
   Operation_Failed : exception;

--************************************************************************
--  Function:     open
--
--  Parameters:   port : a four letter string that needs to be the
--                       name of a COM port (e.g. "COM1")
--
--  Description:  Establishes a connection to the serial port.
--************************************************************************
  procedure open(port : in string);


--************************************************************************
--  Function:     close
--
--  Parameters:   None
--
--  Description:  Terminates the connection to the serial port.
--************************************************************************
   procedure close;


--************************************************************************
--  Function:     set_up_port
--
--  Parameters:   Baud : an integer that sets the baud rate (needs to be
--                       one of these numbers:  1200, 2400, 4800, 9600)
--
--  Description:  Sets the port up with predetermined settings.
--************************************************************************
   procedure set_up_port(baud : in integer;
                         Done : OUT Boolean);

--************************************************************************
--  Function:     get
--
--  Parameters:   Item : A byte of data that is received at the serial port
--
--  Description:  Reads an item from the serial port.
--************************************************************************
   procedure get(item : out byte);


--************************************************************************
--  Function:     put
--
--  Parameters:   Item : A byte of data to put to the serial port
--
--  Description:  Writes an item to the serial port.
--************************************************************************
   procedure put(item : in byte);


--************************************************************************
--  Function:     port_status
--
--  Parameters:   None
--
--  Description:  Returns whether the port is ready to be written/read.
--************************************************************************
   function  port_status return boolean;

end serial;
